@@ -1,23 +1,30 @@
-pub use flume;
-pub use select;
-
 #[macro_use]
 extern crate lazy_static;
-
 #[macro_use]
 mod macro_helpers;
 
+pub use flume;
+#[cfg(feature = "select_rs")]
+pub use select;
+#[cfg(feature = "select_rs")]
+pub mod select_task_expanders;
+
 mod internal_prelude;
 pub mod prelude;
 
+mod hyper_utils;
+mod task_processor;
+mod task_scheduler;
+
+pub mod config;
+pub mod resolver;
+pub mod types;
+
 mod crawler;
 pub use crawler::*;
 mod parser_processor;
 pub use parser_processor::*;
-
-pub mod config;
 pub mod status_filters;
-pub mod types;
 pub use status_filters::Filter as StatusFilter;
 pub mod load_filters;
 pub use load_filters::Filter as LoadFilter;
@@ -25,8 +32,3 @@ pub mod task_filters;
 pub use task_filters::Filter as TaskFilter;
 pub mod task_expanders;
 pub use task_expanders::Expander as TaskExpander;
-pub mod resolver;
-
-mod hyper_utils;
-mod task_processor;
-mod task_scheduler;
